@@ -3,16 +3,16 @@ setMethod("display", signature(object = "mi.lm"),
   cat( "=======================================\n" )
   cat( "Pooled Estimate\n" )
   cat( "=======================================\n" )
-  print( object$call, digits=digits )
-  tab <- cbind( object@lm.mi.pooled[[1]], object@lm.mi.pooled[[2]] )
+  print( object@call, digits=digits )
+  tab <- cbind( object@mi.pooled[[1]], object@mi.pooled[[2]] )
   dimnames( tab )[[2]] <- c( "coef.est", "coef.se" )
   pfround( tab,  digits=digits)
   cat( "\n=======================================\n" )
   cat( "Separate Estimate for each Imputation\n" )
   cat( "=======================================\n" )
-  for( i in 1:length( object@lm.mi.fit ) ){
+  for( i in 1:length( object@mi.fit ) ){
     cat( "\n** Imputation", i, "**\n" )
-    display( object@lm.mi.fit[[i]], digits=digits )
+    display( object@mi.fit[[i]], digits=digits )
   }
 }
 )
@@ -22,16 +22,36 @@ setMethod("display", signature(object = "mi.glm"),
   cat( "=======================================\n" )
   cat( "Pooled Estimate\n" )
   cat( "=======================================\n" )
-  print( object$call, digits=digits )
-  tab <- cbind( object@glm.mi.pooled[[1]], object@glm.mi.pooled[[2]] )
+  print( object@call, digits=digits )
+  tab <- cbind( object@mi.pooled[[1]], object@mi.pooled[[2]] )
   dimnames( tab )[[2]] <- c( "coef.est", "coef.se" )
   pfround( tab,  digits=digits)
   cat( "\n=======================================\n" )
   cat( "Separate Estimate for each Imputation\n" )
   cat( "=======================================\n" )
-  for( i in 1:length( object@glm.mi.fit ) ){
+  for( i in 1:length( object@mi.fit ) ){
     cat( "\n** Imputation", i, "**\n" )
-    display( object@glm.mi.fit[[i]], digits=digits )
+    display( object@mi.fit[[i]], digits=digits )
+  }
+}
+)
+
+
+setMethod("display", signature(object = "mi.mer"),     
+    function ( object, digits=2 ) {
+  cat( "=======================================\n" )
+  cat( "Pooled Estimate\n" )
+  cat( "=======================================\n" )
+  print( object@call, digits=digits )
+  tab <- cbind( object@mer.mi.pooled[[1]], object@mer.mi.pooled[[2]] )
+  dimnames( tab )[[2]] <- c( "coef.est", "coef.se" )
+  pfround( tab,  digits=digits)
+  cat( "\n=======================================\n" )
+  cat( "Separate Estimate for each Imputation\n" )
+  cat( "=======================================\n" )
+  for( i in 1:length( object@mer.mi.fit ) ){
+    cat( "\n** Imputation", i, "**\n" )
+    display( object@mer.mi.fit[[i]], digits=digits )
   }
 }
 )
