@@ -31,7 +31,7 @@ glm.mi <- function (formula, mi.object, family = gaussian, ... )
     
     mi.glm.object <- new("mi.glm",
                           call = call, 
-                          glm.mi.pooled = pooled,
-                          glm.mi.fit = result )
+                          mi.pooled = pooled,
+                          mi.fit = result )
     return( mi.glm.object )
 }
