@@ -1,11 +1,17 @@
 setMethod("se.coef", signature(object = "mi.lm"), 
   function(object){
-  object@lm.mi.pooled$se
+  object@mi.pooled$se
 }
 )
 
 setMethod("se.coef", signature(object = "mi.glm"), 
   function(object){
-  object@glm.mi.pooled$se
+  object@mi.pooled$se
+}
+)
+
+setMethod("se.coef", signature(object = "mi.mer"), 
+  function(object){
+  object@mi.pooled$se
 }
 )
